@@ -1,4 +1,4 @@
-package LabmanSoap;
+package LabmanSoapInternal;
 use strict;
 use SOAP::Lite ( maptype => {} );
 use Data::Dumper;
@@ -9,11 +9,11 @@ VMWare::LabmanSoap - access Vmware Labmanager SOAP API
 
 =head1 VERSION
 
-Version 0.99_1
+Version 0.99
 
 =cut
 
-our $VERSION = '0.99_1';
+our $VERSION = '0.99';
 
 =head1 SYNOPSIS
 
